package org;

import java.util.Set;

import org.infinispan.client.hotrod.RemoteCache;
import org.infinispan.client.hotrod.annotation.ClientCacheEntryCreated;
import org.infinispan.client.hotrod.annotation.ClientCacheEntryModified;
import org.infinispan.client.hotrod.annotation.ClientListener;
import org.infinispan.client.hotrod.event.ClientCacheEntryCreatedEvent;
import org.infinispan.client.hotrod.event.ClientCacheEntryModifiedEvent;

@ClientListener
public class AvgSensorDataListener {
	private final RemoteCache<String, ShipmentData> cache;
	private final Set<String> watchedShipment;

	public AvgSensorDataListener(RemoteCache<String, ShipmentData> cache, Set<String> watchedShipment) {
		this.cache = cache;
		this.watchedShipment = watchedShipment;
	}

	@ClientCacheEntryCreated
	public void entryCreated(ClientCacheEntryCreatedEvent<String> event) {
		for (String oneWatchedShipment : watchedShipment){
			if (event.getKey()!=null && oneWatchedShipment != null && event.getKey().contains(oneWatchedShipment))
				judgeAction(event.getKey());
		}

	}

	@ClientCacheEntryModified
	public void entryModified(ClientCacheEntryModifiedEvent<String> event) {
		for (String oneWatchedShipment : watchedShipment){
//			System.out.println("!!!!!!!!!!!!!!!!!oneWatchedShipment" + oneWatchedShipment);
//			System.out.println("!!!!!!!!!!!!!!!!!event.getKey()" + event.getKey());
			if (event.getKey()!=null && oneWatchedShipment != null && event.getKey().contains(oneWatchedShipment))
				judgeAction(event.getKey());
		}
	}

	private void judgeAction(String key) {
		ShipmentData data = cache.get(key);
		// setup a few test business rules, rules are based on SKU #.
		String skuNo = data.getSkuNumbers();
		if (skuNo.contains("meat") && data.getTemperature() > 15) {
			// business logic: meat's average temperature can't be higher than 15
			System.out.println("Average data is from: " + key + data.getValues());
			System.out.println(" Warning, MEAT shipment is in danger,  current temperature: " + (int) data.getTemperature() + " threshold is 15");
			System.out.println("");
		}
		if (skuNo.contains("metal") && data.getHumidity() > 30) {
			// business logic:metal's average humidity can't be higher than 30
			System.out.println("Average data is from: " + key + data.getValues());
			System.out.println("  Warning, METAL shipment is in danger,  current humidity: " + (int) data.getHumidity() + " threshold is 30");
			System.out.println("");
		}
		if (skuNo.contains("animal") && (data.getTemperature() < 15 || data.getTemperature() > 30 || data.getHumidity() < 20 || data.getHumidity()> 90)) {
			// business logic: animal average temperature can't be lower than 15 or higher than 30 and average humidity need to between 20 and 90
			System.out.println("Average data is from: " + key + data.getValues());
			System.out.println(" Warning, ANIMAL shipment is in danger, current temperature:  " + (int) data.getTemperature() + " threshold is between 15 to 30" + " current humidity: " + (int) data.getHumidity() + " threshold is between 20 to 90");
			System.out.println("");
		} 

	}
}