package org;

import java.util.Collections;
import java.util.HashSet;
import java.util.Set;

import org.infinispan.client.hotrod.RemoteCache;
import org.infinispan.client.hotrod.RemoteCacheManager;
import org.infinispan.client.hotrod.configuration.ConfigurationBuilder;
import org.infinispan.client.hotrod.impl.ConfigurationProperties;


public class Client {

   public static final String CACHE_NAME = "sensor-avg-data";

   public static void main(String[] args) throws Exception {
      // check provided arguments - at least one shipment needs to be specified
      if (args.length < 1) {
         System.err.println("You have to provide list of shipment to watch, at least one!");
         System.exit(1);
      }
      String DATAGRID_IP = args[0];
      args[0] = null;
      Set<String> shipmentToWatch = new HashSet<>(args.length);
      Collections.addAll(shipmentToWatch, args);
      
      // Configure remote cache
      ConfigurationBuilder builder = new ConfigurationBuilder();
      builder.addServer().host(DATAGRID_IP).port(ConfigurationProperties.DEFAULT_HOTROD_PORT);
      RemoteCacheManager cacheManager = new RemoteCacheManager(builder.build());
      RemoteCache<String, ShipmentData> cache = cacheManager.getCache(CACHE_NAME);

      // Add cache listener and wait for specified amount of time
      AvgSensorDataListener avgListener = new AvgSensorDataListener(cache, shipmentToWatch);
      cache.addClientListener(avgListener);
      int LISTEN_TIME = 24; // how long the client should listen to changes, in hours
      System.out.printf("Client will be listening to avg. sensor updates for %d hours%n", LISTEN_TIME);
      Thread.sleep(LISTEN_TIME * 60 * 60 * 1000);

      System.out.println("Stopping client");
      cache.removeClientListener(avgListener);
      cacheManager.stop();
      System.exit(0);
   }

}
