package org;

import java.util.Set;

import org.infinispan.client.hotrod.RemoteCache;
import org.infinispan.client.hotrod.annotation.ClientCacheEntryCreated;
import org.infinispan.client.hotrod.annotation.ClientCacheEntryModified;
import org.infinispan.client.hotrod.annotation.ClientListener;
import org.infinispan.client.hotrod.event.ClientCacheEntryCreatedEvent;
import org.infinispan.client.hotrod.event.ClientCacheEntryModifiedEvent;

@ClientListener
public class AvgSensorDataListener {
	private final RemoteCache<String, ShipmentData> cache;
	private final Set<String> watchedPlaces;

	public AvgSensorDataListener(RemoteCache<String, ShipmentData> cache, Set<String> watchedPlaces) {
		this.cache = cache;
		this.watchedPlaces = watchedPlaces;
	}

	@ClientCacheEntryCreated
	public void entryCreated(ClientCacheEntryCreatedEvent<String> event) {
		if (watchedPlaces.contains(event.getKey()))
			updateAction(event.getKey());
	}

	@ClientCacheEntryModified
	public void entryModified(ClientCacheEntryModifiedEvent<String> event) {
		if (watchedPlaces.contains(event.getKey()))
			updateAction(event.getKey());
	}

	private void updateAction(String key) {
		ShipmentData data = cache.get(key);
		// System.out.printf("[%s] avg. temperature is now %.1f \u00B0C%n", key,
		// cache.get(key));

		// setup a few test warning rules, based on SKU #.
		String skuNo = data.getSkuNumbers();
		if (skuNo.contains("meat") && data.getTemperature() > 15) {
			// meat's average temperature can't be higher than 15
			System.out.println(" Warning, shipment is in danger, data is from " + key + data.getValues());
			System.out.println(" meat shipment's current temperature: " + data.getTemperature());
			System.out.println("");
		} else if (skuNo.contains("metal") && data.getHumidity() > 30) {
			// metal's average humidity can't be higher than 30
			System.out.println(" Warning, shipment is in danger, data is from " + key + data.getValues());
			System.out.println("  metal shipment current humidity: " + data.getHumidity());
			System.out.println("");
		} else if (skuNo.contains("plant")
				&& (data.getHumidity() < 60 || data.getTemperature() < 20 || data.getTemperature() > 40)) {
			// plant's average temperature can't be lower than 20 or higher than
			// 40, and humidity can't be lower than 60
			System.out.println(" Warning, shipment is in danger, data is from " + key + data.getValues());
			System.out.println(" plant shipment current temperature " + data.getTemperature() + " current humidity: "
					+ data.getHumidity());

			System.out.println("");
		} else if (skuNo.contains("animal") && ((data.getTemperature() < 15 || data.getTemperature() > 30))) {
			// animal average temperature can't be lower than 15 or higher than
			// 30
			System.out.println(" Warning, shipment is in danger, data is from " + key + data.getValues());
			System.out.println(" animal shipment current temperature " + data.getTemperature() + " current humidity: "
					+ data.getHumidity());
			System.out.println("");
		} else {
			System.out.println("received average data is from: " + key + data.getValues());

		}

	}
}