package org;

import java.util.Random;
import java.util.Timer;
import java.util.TimerTask;

import org.infinispan.client.hotrod.RemoteCache;
import org.infinispan.client.hotrod.RemoteCacheManager;
import org.infinispan.client.hotrod.configuration.ConfigurationBuilder;
import org.infinispan.client.hotrod.impl.ConfigurationProperties;

public class TestSensor {

	public static final String CACHE_NAME = "sensor-data";
	private static final Random RANDOM = new Random();

	// running for 24 hours
	private static final int GENERATE_INTERVAL = 1000 * 60 * 60 * 24;
	// how often data should be generated, in ms
	private static final int GENERATE_PERIOD = 1000;

	public static void main(String[] args) throws InterruptedException {

		// Configure remote cache
		ConfigurationBuilder builder = new ConfigurationBuilder();
		String DATAGRID_IP = args[0];
		builder.addServer().host(DATAGRID_IP).port(ConfigurationProperties.DEFAULT_HOTROD_PORT);
		RemoteCacheManager cacheManager = new RemoteCacheManager(builder.build());
		RemoteCache<String, ShipmentData> cache = cacheManager.getCache(CACHE_NAME);

		// Insert some sensor data into the cache
		TimerTask randomSensorData = new SensorDataGenerator(cache);
		Timer timer = new Timer(true);
		timer.schedule(randomSensorData, 0, GENERATE_PERIOD);

		// Generate sensor data for specified interval
		Thread.sleep(GENERATE_INTERVAL);
		// Thread.sleep(GENERATE_INTERVAL * 60 * 1000);
		randomSensorData.cancel();
		cacheManager.stop();
		System.exit(0);
	}

	private static class SensorDataGenerator extends TimerTask {
		// maximum temperature for the simulation data range
		private static final int TEMP_MAX = 60;
		// maximum humidity for the simulation data range
		private static final int HUMIDITY_MAX = 100;

		private final RemoteCache<String, ShipmentData> cache;

		public SensorDataGenerator(RemoteCache<String, ShipmentData> cache) {
			this.cache = cache;
		}

		@Override
		public void run() {
			//Simulate 1000 different shipments
			int i = RANDOM.nextInt(1000);

			String shipment = "shipment" + i;
			String sku = "sku_";
			double temperature = RANDOM.nextDouble() * TEMP_MAX;
			double humidity = RANDOM.nextDouble() * HUMIDITY_MAX;
			// setup the fake data, that the first batch of sku# is for meat shipment, next batch is metal, next batch is animal, last batch for combined shipment
			if (i < 250) {
				sku = sku + "meat" + i;
				temperature = RANDOM.nextDouble() * 30;
			}
			if (i >= 250 && i < 500) {
				sku = sku + "metal" + i;
				humidity = RANDOM.nextDouble() * 40;
			}
			if (i >= 500 && i < 750) {
				sku = sku + "animal" + i;
				temperature = RANDOM.nextDouble() * 45;
				humidity = RANDOM.nextDouble() * 75;
			}
			if (i >= 750 && i < 1000) {
				sku = sku + "animal" + i + "," + sku + "metal" + i;
			}

			ShipmentData newShipment = new ShipmentData();
			newShipment.setHumidity(humidity);
			newShipment.setTemperature(temperature);
			newShipment.setSkuNumbers(sku);
			newShipment.setSensorTime(System.currentTimeMillis());

			cache.put(shipment, newShipment);
			System.out.println("Inserted " + shipment + newShipment.getValues());
		}
	}

}
